@@ -22,12 +22,11 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ExecutorService;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.uberfire.commons.async.DescriptiveRunnable;
-import org.uberfire.commons.async.DisposableExecutor;
-import org.uberfire.commons.async.SimpleAsyncExecutorService;
 import org.uberfire.ext.metadata.engine.Indexer;
 import org.uberfire.ext.metadata.engine.MetaIndexEngine;
 import org.uberfire.ext.metadata.engine.Observer;
@@ -55,7 +54,7 @@ import org.uberfire.java.nio.file.WatchService;
 import org.uberfire.java.nio.file.attribute.FileAttribute;
 import org.uberfire.java.nio.file.attribute.FileAttributeView;
 
-import static org.uberfire.commons.validation.PortablePreconditions.checkNotNull;
+import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 import static org.uberfire.java.nio.file.StandardWatchEventKind.ENTRY_CREATE;
 import static org.uberfire.java.nio.file.StandardWatchEventKind.ENTRY_MODIFY;
 
@@ -67,49 +66,59 @@ public class IOServiceIndexedImpl extends IOServiceDotFileImpl {
     private final BatchIndex batchIndex;
 
     private final Class<? extends FileAttributeView>[] views;
-    private final List<FileSystem> watchedList = new ArrayList<FileSystem>();
+    private final List<String> watchedList = new ArrayList<>();
     private final List<WatchService> watchServices = new ArrayList<WatchService>();
 
     private final Observer observer;
+    private ExecutorService executorService;
 
     public IOServiceIndexedImpl(final MetaIndexEngine indexEngine,
+                                final ExecutorService executorService,
                                 final Class<? extends FileAttributeView>... views) {
         this(indexEngine,
              new NOPObserver(),
+             executorService,
              views);
     }
 
     public IOServiceIndexedImpl(final String id,
                                 final MetaIndexEngine indexEngine,
+                                final ExecutorService executorService,
                                 final Class<? extends FileAttributeView>... views) {
         this(id,
              indexEngine,
              new NOPObserver(),
+             executorService,
              views);
     }
 
     public IOServiceIndexedImpl(final IOWatchService watchService,
                                 final MetaIndexEngine indexEngine,
+                                final ExecutorService executorService,
                                 final Class<? extends FileAttributeView>... views) {
         this(watchService,
              indexEngine,
              new NOPObserver(),
+             executorService,
              views);
     }
 
     public IOServiceIndexedImpl(final String id,
                                 final IOWatchService watchService,
                                 final MetaIndexEngine indexEngine,
+                                final ExecutorService executorService,
                                 final Class<? extends FileAttributeView>... views) {
         this(id,
              watchService,
              indexEngine,
              new NOPObserver(),
+             executorService,
              views);
     }
 
     public IOServiceIndexedImpl(final MetaIndexEngine indexEngine,
                                 final Observer observer,
+                                final ExecutorService executorService,
                                 final Class<? extends FileAttributeView>... views) {
         super();
         this.indexEngine = checkNotNull("indexEngine",
@@ -119,13 +128,17 @@ public class IOServiceIndexedImpl extends IOServiceDotFileImpl {
         this.batchIndex = new BatchIndex(indexEngine,
                                          this,
                                          observer,
+                                         executorService,
                                          views);
         this.views = views;
+
+        this.executorService = executorService;
     }
 
     public IOServiceIndexedImpl(final String id,
                                 final MetaIndexEngine indexEngine,
                                 final Observer observer,
+                                final ExecutorService executorService,
                                 final Class<? extends FileAttributeView>... views) {
         super(id);
         this.indexEngine = checkNotNull("indexEngine",
@@ -135,13 +148,16 @@ public class IOServiceIndexedImpl extends IOServiceDotFileImpl {
         this.batchIndex = new BatchIndex(indexEngine,
                                          this,
                                          observer,
+                                         executorService,
                                          views);
         this.views = views;
+        this.executorService = executorService;
     }
 
     public IOServiceIndexedImpl(final IOWatchService watchService,
                                 final MetaIndexEngine indexEngine,
                                 final Observer observer,
+                                final ExecutorService executorService,
                                 final Class<? extends FileAttributeView>... views) {
         super(watchService);
         this.indexEngine = checkNotNull("indexEngine",
@@ -151,14 +167,18 @@ public class IOServiceIndexedImpl extends IOServiceDotFileImpl {
         this.batchIndex = new BatchIndex(indexEngine,
                                          this,
                                          observer,
+                                         executorService,
                                          views);
         this.views = views;
+
+        this.executorService = executorService;
     }
 
     public IOServiceIndexedImpl(final String id,
                                 final IOWatchService watchService,
                                 final MetaIndexEngine indexEngine,
                                 final Observer observer,
+                                final ExecutorService executorService,
                                 final Class<? extends FileAttributeView>... views) {
         super(id,
               watchService);
@@ -169,28 +189,21 @@ public class IOServiceIndexedImpl extends IOServiceDotFileImpl {
         this.batchIndex = new BatchIndex(indexEngine,
                                          this,
                                          observer,
+                                         executorService,
                                          views);
         this.views = views;
+
+        this.executorService = executorService;
     }
 
     @Override
     public FileSystem getFileSystem(final URI uri)
             throws IllegalArgumentException, FileSystemNotFoundException,
             ProviderNotFoundException, SecurityException {
-        try {
-            final FileSystem fs = super.getFileSystem(uri);
-            indexIfFresh(fs);
-            setupWatchService(fs);
-            return fs;
-        } catch (final IllegalArgumentException ex) {
-            throw ex;
-        } catch (final FileSystemNotFoundException ex) {
-            throw ex;
-        } catch (final ProviderNotFoundException ex) {
-            throw ex;
-        } catch (final SecurityException ex) {
-            throw ex;
-        }
+        final FileSystem fs = super.getFileSystem(uri);
+        indexIfFresh(fs);
+        setupWatchService(fs);
+        return fs;
     }
 
     @Override
@@ -198,23 +211,11 @@ public class IOServiceIndexedImpl extends IOServiceDotFileImpl {
                                     final Map<String, ?> env)
             throws IllegalArgumentException, FileSystemAlreadyExistsException,
             ProviderNotFoundException, IOException, SecurityException {
-        try {
-            final FileSystem fs = super.newFileSystem(uri,
-                                                      env);
-            index(fs);
-            setupWatchService(fs);
-            return fs;
-        } catch (final IllegalArgumentException ex) {
-            throw ex;
-        } catch (final FileSystemAlreadyExistsException ex) {
-            throw ex;
-        } catch (final ProviderNotFoundException ex) {
-            throw ex;
-        } catch (final IOException ex) {
-            throw ex;
-        } catch (final SecurityException ex) {
-            throw ex;
-        }
+        final FileSystem fs = super.newFileSystem(uri,
+                                                  env);
+        index(fs);
+        setupWatchService(fs);
+        return fs;
     }
 
     @Override
@@ -231,17 +232,16 @@ public class IOServiceIndexedImpl extends IOServiceDotFileImpl {
     }
 
     protected void setupWatchService(final FileSystem fs) {
-        if (watchedList.contains(fs)) {
+        if (watchedList.contains(fs.getName())) {
             return;
         }
         final WatchService ws = fs.newWatchService();
-        watchedList.add(fs);
+        watchedList.add(fs.getName());
         watchServices.add(ws);
 
-        final DisposableExecutor defaultInstance = SimpleAsyncExecutorService.getDefaultInstance();
-        final DisposableExecutor unmanagedInstance = SimpleAsyncExecutorService.getUnmanagedInstance();
+        final ExecutorService defaultInstance = this.executorService;
 
-        SimpleAsyncExecutorService.getUnmanagedInstance().execute(new DescriptiveRunnable() {
+        defaultInstance.execute(new DescriptiveRunnable() {
             @Override
             public String getDescription() {
                 return "IOServiceIndexedImpl(" + ws.toString() + ")";
@@ -379,14 +379,7 @@ public class IOServiceIndexedImpl extends IOServiceDotFileImpl {
                             return isDisposed || ws.isClose();
                         }
                     };
-                    if (defaultInstance.equals(unmanagedInstance)) {
-                        // if default and unmanaged are same instance simply run the job to avoid duplicated threads
-                        job.run();
-                    } else {
-                        // whenever events are found submit the actual operation to the executor to avoid blocking thread
-                        // and to have correct scope on application servers to gain access to CDI beans
-                        defaultInstance.execute(job);
-                    }
+                    defaultInstance.execute(job);
                 }
             }
         });
